#ifndef NT2_INCLUDE_FUNCTIONS_LOGICAL_XOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGICAL_XOR_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/logical_xor.hpp>

#endif
